/****************************************************************************
** Meta object code from reading C++ file 'dockpreviewcontextv1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/modules/foreign-toplevel/dockpreviewcontextv1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockpreviewcontextv1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20DockPreviewContextV1E_t {};
} // unnamed namespace

template <> constexpr inline auto DockPreviewContextV1::qt_create_metaobjectdata<qt_meta_tag_ZN20DockPreviewContextV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DockPreviewContextV1",
        "requestShow",
        "",
        "QPoint",
        "pos",
        "ForeignToplevelManagerInterfaceV1::PreviewDirection",
        "direction",
        "QList<ForeignToplevelHandleV1*>",
        "toplevels",
        "requestShowTooltip",
        "tooltip",
        "requestClose",
        "beforeDestroy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestShow'
        QtMocHelpers::SignalData<void(const QPoint &, ForeignToplevelManagerInterfaceV1::PreviewDirection, const QList<ForeignToplevelHandleV1*> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'requestShowTooltip'
        QtMocHelpers::SignalData<void(const QString &, const QPoint &, ForeignToplevelManagerInterfaceV1::PreviewDirection)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'requestClose'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'beforeDestroy'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DockPreviewContextV1, qt_meta_tag_ZN20DockPreviewContextV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DockPreviewContextV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DockPreviewContextV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DockPreviewContextV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DockPreviewContextV1E_t>.metaTypes,
    nullptr
} };

void DockPreviewContextV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockPreviewContextV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestShow((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ForeignToplevelManagerInterfaceV1::PreviewDirection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<ForeignToplevelHandleV1*>>>(_a[3]))); break;
        case 1: _t->requestShowTooltip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ForeignToplevelManagerInterfaceV1::PreviewDirection>>(_a[3]))); break;
        case 2: _t->requestClose(); break;
        case 3: _t->beforeDestroy(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockPreviewContextV1::*)(const QPoint & , ForeignToplevelManagerInterfaceV1::PreviewDirection , const QList<ForeignToplevelHandleV1*> & )>(_a, &DockPreviewContextV1::requestShow, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockPreviewContextV1::*)(const QString & , const QPoint & , ForeignToplevelManagerInterfaceV1::PreviewDirection )>(_a, &DockPreviewContextV1::requestShowTooltip, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockPreviewContextV1::*)()>(_a, &DockPreviewContextV1::requestClose, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockPreviewContextV1::*)()>(_a, &DockPreviewContextV1::beforeDestroy, 3))
            return;
    }
}

const QMetaObject *DockPreviewContextV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockPreviewContextV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DockPreviewContextV1E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DockPreviewContextV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DockPreviewContextV1::requestShow(const QPoint & _t1, ForeignToplevelManagerInterfaceV1::PreviewDirection _t2, const QList<ForeignToplevelHandleV1*> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void DockPreviewContextV1::requestShowTooltip(const QString & _t1, const QPoint & _t2, ForeignToplevelManagerInterfaceV1::PreviewDirection _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void DockPreviewContextV1::requestClose()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DockPreviewContextV1::beforeDestroy()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
